OC.L10N.register(
    "photos",
    {
    "Photos" : "Suratlar",
    "Videos" : "Wideo",
    "Favorites" : "Halanýanlar",
    "Tags" : "Bellikler",
    "Back" : "Yzyna",
    "Save" : "Saklamak",
    "Favorite" : "Halaýan",
    "Download" : "Göçürip almak",
    "Delete" : "Pozmak",
    "Settings" : "Sazlamalar"
},
"nplurals=2; plural=(n != 1);");
